@@ -1,8 +1,8 @@
-#!/usr/local/bin/perl
+#! /usr/local/bin/perl
 
 use strict;
 use warnings;
-use Filesys::getfsent;
+use Filesys::getfsent qw(getfsent);
 
 while (my @entry = getfsent()) {
     print "@entry\n";
